'filesysobjects.NetFiles' - Module
**********************************

.. automodule:: filesysobjects.NetFiles

Functions
---------

netNormpathX
^^^^^^^^^^^^
	.. autofunction:: netNormpathX

See also
--------

* For syntax design requirements refer to "`Extended Filesystems - Network Features <path_netfiles.html>`_".

* See also Python issue:
    Issue 26329: os.path.normpath("//") returns //
    - http://bugs.python.org/issue26329

